from typing import Annotated

from fastapi import APIRouter, Depends

from fastfood_two.application.contracts.requests import AddMenuDTO
from fastfood_two.application.contracts.responses import MenuDTO
from fastfood_two.application.usecases.menu.add_menu import AddMenu
from fastfood_two.application.usecases.menu.get_all_menus import GetAllMenus
from fastfood_two.presentation.fastapi_backend.depends.stub import Stub
from fastfood_two.presentation.fastapi_backend.pdmodels.menu import AddMenuPDModel

router = APIRouter(prefix="/menu", tags=["Menu"])


@router.get("/", response_model=list[MenuDTO])
async def get_all_menus(
    usecase: Annotated[GetAllMenus, Depends(Stub(GetAllMenus))],
) -> list[MenuDTO]:
    """Get all menus.

    Endpoint returns list of all available food menus
    """
    menus = await usecase()
    return menus


@router.post("/", response_model=MenuDTO)
async def add_menu(
    request: AddMenuPDModel,
    usecase: Annotated[AddMenu, Depends(Stub(AddMenu))],
) -> MenuDTO:
    """Get all menus.

    Endpoint returns list of all available food menus
    """
    menus = await usecase(request=AddMenuDTO(title=request.title, description=request.description))
    return menus
